"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var react_1 = require("react");
var MqlContext_1 = __importDefault(require("../../../context/MqlContext/MqlContext"));
var CreateMqlQuery_1 = __importDefault(require("../../../mutations/mql/CreateMqlQuery"));
var MqlQueryTypes_1 = require("../../../queries/mql/MqlQueryTypes");
var mqlQueryReducer_1 = require("../../reducers/mqlQueryReducer");
var getErrorMessage_1 = __importDefault(require("../../utils/getErrorMessage"));
var clearEmptyConstraints_1 = __importDefault(require("./clearEmptyConstraints"));
var useCreateTimeSeriesMqlQuery = function (_a) {
    var metricName = _a.metricName, metricNames = _a.metricNames, _b = _a.formState, formState = _b === void 0 ? {} : _b, dispatch = _a.dispatch, retries = _a.retries, refetchMqlQueryAttempt = _a.refetchMqlQueryAttempt;
    var _c = react_1.useContext(MqlContext_1.default), useMutation = _c.useMutation, handleCombinedError = _c.handleCombinedError;
    var _d = useMutation(CreateMqlQuery_1.default), createMqlQueryMutation = _d[1];
    var metrics = react_1.useMemo(function () { return (metricName ? [metricName] : metricNames || []); }, [metricName, metricNames]);
    var createTimeSeriesMqlQuery = function (_a) {
        var stateRetries = _a.stateRetries;
        createMqlQueryMutation({
            addTimeSeries: (formState === null || formState === void 0 ? void 0 : formState.addTimeSeries) !== false,
            attemptNum: stateRetries,
            cacheMode: refetchMqlQueryAttempt ? MqlQueryTypes_1.CacheMode.Ignore : undefined,
            daysLimit: formState.daysLimit,
            endTime: formState.latestXDays ? null : formState.endTime,
            groupBy: formState.groupBy || [],
            includeDateBoundaries: formState.includeDateBoundaries,
            latestXDays: formState.latestXDays,
            limit: formState.limit,
            maxDimensionValues: formState.maxDimensionValues,
            metrics: metrics,
            order: formState.order,
            pctChange: formState.pctChange || null,
            startTime: formState.latestXDays ? null : formState.startTime,
            timeGranularity: formState.timeGranularity || null,
            trimIncompletePeriods: formState.trimIncompletePeriods,
            where: clearEmptyConstraints_1.default(formState.where),
        }).then(function (_a) {
            var _b, _c, _d, _e;
            var data = _a.data, error = _a.error;
            if (((_c = (_b = data === null || data === void 0 ? void 0 : data.createMqlQuery) === null || _b === void 0 ? void 0 : _b.query) === null || _c === void 0 ? void 0 : _c.status) === MqlQueryTypes_1.MqlQueryStatus.Successful) {
                dispatch({
                    type: 'postQueryCachedResultsSuccess',
                    data: data,
                    handleCombinedError: handleCombinedError,
                });
            }
            else {
                if ((_d = data === null || data === void 0 ? void 0 : data.createMqlQuery) === null || _d === void 0 ? void 0 : _d.id) {
                    dispatch({
                        type: 'postQuerySuccess',
                        queryId: (_e = data === null || data === void 0 ? void 0 : data.createMqlQuery) === null || _e === void 0 ? void 0 : _e.id,
                    });
                    return;
                }
                if (error) {
                    if (retries > 0 &&
                        stateRetries !== retries &&
                        stateRetries < retries) {
                        setTimeout(function () {
                            dispatch({ type: 'retryFetchResults' });
                            createTimeSeriesMqlQuery({ stateRetries: stateRetries + 1 });
                        }, mqlQueryReducer_1.getRetryPollingMS());
                    }
                    else {
                        dispatch({
                            type: 'postQueryFail',
                            errorMessage: getErrorMessage_1.default(error),
                        });
                    }
                    handleCombinedError(error);
                }
            }
        });
    };
    return {
        createTimeSeriesMqlQuery: createTimeSeriesMqlQuery,
    };
};
exports.default = useCreateTimeSeriesMqlQuery;
